Struct google_keep1::api::BatchDeletePermissionsRequest
source · pub struct BatchDeletePermissionsRequest {
pub names: Option<Vec<String>>,
}Expand description
The request to remove one or more permissions from a note. A permission with the OWNER role can’t be removed. If removing a permission fails, then the entire request fails and no changes are made. Returns a 400 bad request error if a specified permission does not exist on the note.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- permissions batch delete notes (request)
Fields
names: Option<Vec<String>>Required. The names of the permissions to delete. Format: notes/{note}/permissions/{permission}