Struct google_keep1::api::ListContent
source · pub struct ListContent {
pub list_items: Option<Vec<ListItem>>,
}Expand description
The list of items for a single list note.
This type is not used in any activity, and only used as part of another schema.
Fields
list_items: Option<Vec<ListItem>>The items in the list. The number of items must be less than 1,000.