Struct google_keep1::api::ListItem
source · pub struct ListItem {
pub checked: Option<bool>,
pub child_list_items: Option<Vec<ListItem>>,
pub text: Option<TextContent>,
}Expand description
A single list item in a note’s list.
This type is not used in any activity, and only used as part of another schema.
Fields
checked: Option<bool>Whether this item has been checked off or not.
child_list_items: Option<Vec<ListItem>>If set, list of list items nested under this list item. Only one level of nesting is allowed.
text: Option<TextContent>The text of this item. Length must be less than 1,000 characters.