pub struct Permission {
pub deleted: Option<bool>,
pub email: Option<String>,
pub family: Option<Family>,
pub group: Option<Group>,
pub name: Option<String>,
pub role: Option<String>,
pub user: Option<User>,
}Expand description
A single permission on the note. Associates a member with a role.
This type is not used in any activity, and only used as part of another schema.
Fields
deleted: Option<bool>Output only. Whether this member has been deleted. If the member is recovered, this value is set to false and the recovered member retains the role on the note.
email: Option<String>The email associated with the member. If set on create, the email field in the User or Group message must either be empty or match this field. On read, may be unset if the member does not have an associated email.
family: Option<Family>Output only. The Google Family to which this role applies.
group: Option<Group>Output only. The group to which this role applies.
name: Option<String>Output only. The resource name.
role: Option<String>The role granted by this permission. The role determines the entity’s ability to read, write, and share notes.
user: Option<User>Output only. The user to whom this role applies.