Struct google_keep1::api::Section
source · pub struct Section {
pub list: Option<ListContent>,
pub text: Option<TextContent>,
}Expand description
The content of the note.
This type is not used in any activity, and only used as part of another schema.
Fields
list: Option<ListContent>Used if this section’s content is a list.
text: Option<TextContent>Used if this section’s content is a block of text. The length of the text content must be less than 20,000 characters.