Struct google_keep1::api::TextContent
source · pub struct TextContent {
pub text: Option<String>,
}Expand description
The block of text for a single text section or list item.
This type is not used in any activity, and only used as part of another schema.
Fields
text: Option<String>The text of the note. The limits on this vary with the specific field using this type.